Method: AssemblyAI::Lemur::LemurQuestionContext.from_json
- Defined in:
- lib/assemblyai/lemur/types/lemur_question_context.rb
.from_json(json_object:) ⇒ AssemblyAI::Lemur::LemurQuestionContext
Deserialize a JSON object to an instance of LemurQuestionContext
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/assemblyai/lemur/types/lemur_question_context.rb', line 14 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) begin struct.is_a?(String) != false || raise("Passed value for field struct is not the expected type, validation failed.") return json_object unless json_object.nil? return nil rescue StandardError # noop end begin struct.is_a?(Hash) != false || raise("Passed value for field struct is not the expected type, validation failed.") return json_object unless json_object.nil? return nil rescue StandardError # noop end struct end |