Class: AssemblyAI::Transcripts::SentimentAnalysisResult

Inherits:
Object
  • Object
show all
Defined in:
lib/assemblyai/transcripts/types/sentiment_analysis_result.rb

Overview

The result of the Sentiment Analysis model

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(text:, start:, end_:, sentiment:, confidence:, speaker: OMIT, additional_properties: nil) ⇒ AssemblyAI::Transcripts::SentimentAnalysisResult

Parameters:

  • text (String)

    The transcript of the sentence

  • start (Integer)

    The starting time, in milliseconds, of the sentence

  • end_ (Integer)

    The ending time, in milliseconds, of the sentence

  • sentiment (AssemblyAI::Transcripts::Sentiment)

    The detected sentiment for the sentence, one of POSITIVE, NEUTRAL, NEGATIVE

  • confidence (Float)

    The confidence score for the detected sentiment of the sentence, from 0 to 1

  • speaker (String) (defaults to: OMIT)

    The speaker of the sentence if [Speaker Diarization](www.assemblyai.com/docs/models/speaker-diarization) is enabled, else null

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 43

def initialize(text:, start:, end_:, sentiment:, confidence:, speaker: OMIT, additional_properties: nil)
  @text = text
  @start = start
  @end_ = end_
  @sentiment = sentiment
  @confidence = confidence
  @speaker = speaker if speaker != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "text": text,
    "start": start,
    "end": end_,
    "sentiment": sentiment,
    "confidence": confidence,
    "speaker": speaker
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



26
27
28
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 26

def additional_properties
  @additional_properties
end

#confidenceFloat (readonly)

Returns The confidence score for the detected sentiment of the sentence, from 0 to 1.

Returns:

  • (Float)

    The confidence score for the detected sentiment of the sentence, from 0 to 1



20
21
22
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 20

def confidence
  @confidence
end

#end_Integer (readonly)

Returns The ending time, in milliseconds, of the sentence.

Returns:

  • (Integer)

    The ending time, in milliseconds, of the sentence



16
17
18
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 16

def end_
  @end_
end

#sentimentAssemblyAI::Transcripts::Sentiment (readonly)

Returns The detected sentiment for the sentence, one of POSITIVE, NEUTRAL, NEGATIVE.

Returns:



18
19
20
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 18

def sentiment
  @sentiment
end

#speakerString (readonly)

Returns The speaker of the sentence if [Speaker Diarization](www.assemblyai.com/docs/models/speaker-diarization) is enabled, else null.

Returns:



24
25
26
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 24

def speaker
  @speaker
end

#startInteger (readonly)

Returns The starting time, in milliseconds, of the sentence.

Returns:

  • (Integer)

    The starting time, in milliseconds, of the sentence



14
15
16
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 14

def start
  @start
end

#textString (readonly)

Returns The transcript of the sentence.

Returns:

  • (String)

    The transcript of the sentence



12
13
14
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 12

def text
  @text
end

Class Method Details

.from_json(json_object:) ⇒ AssemblyAI::Transcripts::SentimentAnalysisResult

Deserialize a JSON object to an instance of SentimentAnalysisResult

Parameters:

  • json_object (String)

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 67

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  text = struct["text"]
  start = struct["start"]
  end_ = struct["end"]
  sentiment = struct["sentiment"]
  confidence = struct["confidence"]
  speaker = struct["speaker"]
  new(
    text: text,
    start: start,
    end_: end_,
    sentiment: sentiment,
    confidence: confidence,
    speaker: speaker,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


99
100
101
102
103
104
105
106
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 99

def self.validate_raw(obj:)
  obj.text.is_a?(String) != false || raise("Passed value for field obj.text is not the expected type, validation failed.")
  obj.start.is_a?(Integer) != false || raise("Passed value for field obj.start is not the expected type, validation failed.")
  obj.end_.is_a?(Integer) != false || raise("Passed value for field obj.end_ is not the expected type, validation failed.")
  obj.sentiment.is_a?(AssemblyAI::Transcripts::Sentiment) != false || raise("Passed value for field obj.sentiment is not the expected type, validation failed.")
  obj.confidence.is_a?(Float) != false || raise("Passed value for field obj.confidence is not the expected type, validation failed.")
  obj.speaker&.is_a?(String) != false || raise("Passed value for field obj.speaker is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of SentimentAnalysisResult to a JSON object

Returns:

  • (String)


89
90
91
# File 'lib/assemblyai/transcripts/types/sentiment_analysis_result.rb', line 89

def to_json(*_args)
  @_field_set&.to_json
end